==> selenium-selenium-4.31.0.gh.tar.gz: selenium-selenium-4.31.0/dotnet/src/webdriver/HttpRequestData.cs <==
// <copyright file="HttpRequestData.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System.Collections.Generic;

namespace OpenQA.Selenium
{
    /// <summary>
    /// Represents the response data for an intercepted HTTP call.
    /// </summary>
    public class HttpRequestData
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="HttpRequestData"/> type.
        /// </summary>
        public HttpRequestData()
        {
        }

        /// <summary>
        /// Gets the method of the HTTP request.
        /// </summary>
        public string? Method { get; set; }

        /// <summary>
        /// Gets the URL of the HTTP request.
        /// </summary>
        public string? Url { get; set; }

        /// <summary>
        /// Gets the POST data of the HTTP request, if any.
        /// </summary>
        public string? PostData { get; set; }

        /// <summary>
        /// Gets the headers of the HTTP request.
        /// </summary>
        public Dictionary<string, string>? Headers { get; set; }

        /// <summary>
        /// Gets the ID of the HTTP request.
        /// </summary>
        public string? RequestId { get; internal set; }
    }
}

==> selenium-selenium-4.39.0.gh.tar.gz: selenium-selenium-4.39.0/dotnet/src/webdriver/HttpRequestData.cs <==
// <copyright file="HttpRequestData.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System.Collections.Generic;

namespace OpenQA.Selenium;

/// <summary>
/// Represents the response data for an intercepted HTTP call.
/// </summary>
public class HttpRequestData
{
    /// <summary>
    /// Initializes a new instance of the <see cref="HttpRequestData"/> type.
    /// </summary>
    public HttpRequestData()
    {
    }

    /// <summary>
    /// Gets the method of the HTTP request.
    /// </summary>
    public string? Method { get; set; }

    /// <summary>
    /// Gets the URL of the HTTP request.
    /// </summary>
    public string? Url { get; set; }

    /// <summary>
    /// Gets the POST data of the HTTP request, if any.
    /// </summary>
    public string? PostData { get; set; }

    /// <summary>
    /// Gets the headers of the HTTP request.
    /// </summary>
    public Dictionary<string, string>? Headers { get; set; }

    /// <summary>
    /// Gets the ID of the HTTP request.
    /// </summary>
    public string? RequestId { get; internal set; }
}
